from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.ServerBackup
WSB_MAX_OB_STATUS_VALUE_TYPE_PAIR: UInt32 = 5
WSB_MAX_OB_STATUS_ENTRY: UInt32 = 5
WSBAPP_ASYNC_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = 7995396
class IWsbApplicationAsync(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0843f6f7-895c-44a6-b0c2-05a5022aa3a1}')
    @commethod(3)
    def QueryStatus(self, phrResult: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Abort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWsbApplicationBackupSupport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1eff3510-4a27-46ad-b9e0-08332f0f4f6d}')
    @commethod(3)
    def CheckConsistency(self, wszWriterMetadata: win32more.Windows.Win32.Foundation.PWSTR, wszComponentName: win32more.Windows.Win32.Foundation.PWSTR, wszComponentLogicalPath: win32more.Windows.Win32.Foundation.PWSTR, cVolumes: UInt32, rgwszSourceVolumePath: POINTER(win32more.Windows.Win32.Foundation.PWSTR), rgwszSnapshotVolumePath: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppAsync: POINTER(win32more.Windows.Win32.System.ServerBackup.IWsbApplicationAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWsbApplicationRestoreSupport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8d3bdb38-4ee8-4718-85f9-c7dbc4ab77aa}')
    @commethod(3)
    def PreRestore(self, wszWriterMetadata: win32more.Windows.Win32.Foundation.PWSTR, wszComponentName: win32more.Windows.Win32.Foundation.PWSTR, wszComponentLogicalPath: win32more.Windows.Win32.Foundation.PWSTR, bNoRollForward: win32more.Windows.Win32.Foundation.BOOLEAN) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def PostRestore(self, wszWriterMetadata: win32more.Windows.Win32.Foundation.PWSTR, wszComponentName: win32more.Windows.Win32.Foundation.PWSTR, wszComponentLogicalPath: win32more.Windows.Win32.Foundation.PWSTR, bNoRollForward: win32more.Windows.Win32.Foundation.BOOLEAN) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OrderComponents(self, cComponents: UInt32, rgComponentName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), rgComponentLogicalPaths: POINTER(win32more.Windows.Win32.Foundation.PWSTR), prgComponentName: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR)), prgComponentLogicalPath: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def IsRollForwardSupported(self, pbRollForwardSupported: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class WSB_OB_REGISTRATION_INFO(Structure):
    m_wszResourceDLL: win32more.Windows.Win32.Foundation.PWSTR
    m_guidSnapinId: Guid
    m_dwProviderName: UInt32
    m_dwProviderIcon: UInt32
    m_bSupportsRemoting: win32more.Windows.Win32.Foundation.BOOLEAN
class WSB_OB_STATUS_ENTRY(Structure):
    m_dwIcon: UInt32
    m_dwStatusEntryName: UInt32
    m_dwStatusEntryValue: UInt32
    m_cValueTypePair: UInt32
    m_rgValueTypePair: POINTER(win32more.Windows.Win32.System.ServerBackup.WSB_OB_STATUS_ENTRY_VALUE_TYPE_PAIR)
WSB_OB_STATUS_ENTRY_PAIR_TYPE = Int32
WSB_OB_ET_UNDEFINED: win32more.Windows.Win32.System.ServerBackup.WSB_OB_STATUS_ENTRY_PAIR_TYPE = 0
WSB_OB_ET_STRING: win32more.Windows.Win32.System.ServerBackup.WSB_OB_STATUS_ENTRY_PAIR_TYPE = 1
WSB_OB_ET_NUMBER: win32more.Windows.Win32.System.ServerBackup.WSB_OB_STATUS_ENTRY_PAIR_TYPE = 2
WSB_OB_ET_DATETIME: win32more.Windows.Win32.System.ServerBackup.WSB_OB_STATUS_ENTRY_PAIR_TYPE = 3
WSB_OB_ET_TIME: win32more.Windows.Win32.System.ServerBackup.WSB_OB_STATUS_ENTRY_PAIR_TYPE = 4
WSB_OB_ET_SIZE: win32more.Windows.Win32.System.ServerBackup.WSB_OB_STATUS_ENTRY_PAIR_TYPE = 5
WSB_OB_ET_MAX: win32more.Windows.Win32.System.ServerBackup.WSB_OB_STATUS_ENTRY_PAIR_TYPE = 6
class WSB_OB_STATUS_ENTRY_VALUE_TYPE_PAIR(Structure):
    m_wszObStatusEntryPairValue: win32more.Windows.Win32.Foundation.PWSTR
    m_ObStatusEntryPairType: win32more.Windows.Win32.System.ServerBackup.WSB_OB_STATUS_ENTRY_PAIR_TYPE
class WSB_OB_STATUS_INFO(Structure):
    m_guidSnapinId: Guid
    m_cStatusEntry: UInt32
    m_rgStatusEntry: POINTER(win32more.Windows.Win32.System.ServerBackup.WSB_OB_STATUS_ENTRY)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Management.Setup
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class AgentProvisioningProgressReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport
    _classid_ = 'Windows.Management.Setup.AgentProvisioningProgressReport'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Management.Setup.AgentProvisioningProgressReport.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Management.Setup.AgentProvisioningProgressReport: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport) -> win32more.Windows.Management.Setup.DeploymentAgentProgressState: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport, value: win32more.Windows.Management.Setup.DeploymentAgentProgressState) -> Void: ...
    @winrt_mixinmethod
    def get_ProgressPercentage(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport) -> Double: ...
    @winrt_mixinmethod
    def put_ProgressPercentage(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_EstimatedTimeRemaining(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_EstimatedTimeRemaining(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayProgress(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayProgress(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayProgressSecondary(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayProgressSecondary(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Batches(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Management.Setup.DeploymentWorkloadBatch]: ...
    @winrt_mixinmethod
    def get_CurrentBatchIndex(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport) -> UInt32: ...
    @winrt_mixinmethod
    def put_CurrentBatchIndex(self: win32more.Windows.Management.Setup.IAgentProvisioningProgressReport, value: UInt32) -> Void: ...
    Batches = property(get_Batches, None)
    CurrentBatchIndex = property(get_CurrentBatchIndex, put_CurrentBatchIndex)
    DisplayProgress = property(get_DisplayProgress, put_DisplayProgress)
    DisplayProgressSecondary = property(get_DisplayProgressSecondary, put_DisplayProgressSecondary)
    EstimatedTimeRemaining = property(get_EstimatedTimeRemaining, put_EstimatedTimeRemaining)
    ProgressPercentage = property(get_ProgressPercentage, put_ProgressPercentage)
    State = property(get_State, put_State)
class DeploymentAgentProgressState(Enum, Int32):
    NotStarted = 0
    Initializing = 1
    InProgress = 2
    Completed = 3
    ErrorOccurred = 4
    RebootRequired = 5
    Canceled = 6
class DeploymentSessionConnectionChange(Enum, Int32):
    NoChange = 0
    HostConnectionLost = 1
    HostConnectionRestored = 2
    AgentConnectionLost = 3
    AgentConnectionRestored = 4
    InternetConnectionLost = 5
    InternetConnectionRestored = 6
class DeploymentSessionConnectionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Management.Setup.IDeploymentSessionConnectionChangedEventArgs
    _classid_ = 'Windows.Management.Setup.DeploymentSessionConnectionChangedEventArgs'
    @winrt_mixinmethod
    def get_SessionId(self: win32more.Windows.Management.Setup.IDeploymentSessionConnectionChangedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Change(self: win32more.Windows.Management.Setup.IDeploymentSessionConnectionChangedEventArgs) -> win32more.Windows.Management.Setup.DeploymentSessionConnectionChange: ...
    Change = property(get_Change, None)
    SessionId = property(get_SessionId, None)
class DeploymentSessionHeartbeatRequested(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c94a770b-5b05-4595-9e69-79070484377e}')
    @winrt_commethod(3)
    def Invoke(self, eventArgs: win32more.Windows.Management.Setup.DeploymentSessionHeartbeatRequestedEventArgs) -> Void: ...
class DeploymentSessionHeartbeatRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Management.Setup.IDeploymentSessionHeartbeatRequestedEventArgs
    _classid_ = 'Windows.Management.Setup.DeploymentSessionHeartbeatRequestedEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.Management.Setup.IDeploymentSessionHeartbeatRequestedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Windows.Management.Setup.IDeploymentSessionHeartbeatRequestedEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class DeploymentSessionStateChange(Enum, Int32):
    NoChange = 0
    CancelRequestedByUser = 1
    RetryRequestedByUser = 2
class DeploymentSessionStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Management.Setup.IDeploymentSessionStateChangedEventArgs
    _classid_ = 'Windows.Management.Setup.DeploymentSessionStateChangedEventArgs'
    @winrt_mixinmethod
    def get_SessionId(self: win32more.Windows.Management.Setup.IDeploymentSessionStateChangedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Change(self: win32more.Windows.Management.Setup.IDeploymentSessionStateChangedEventArgs) -> win32more.Windows.Management.Setup.DeploymentSessionStateChange: ...
    Change = property(get_Change, None)
    SessionId = property(get_SessionId, None)
class DeploymentWorkload(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Management.Setup.IDeploymentWorkload
    _classid_ = 'Windows.Management.Setup.DeploymentWorkload'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Management.Setup.DeploymentWorkload.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.Management.Setup.IDeploymentWorkloadFactory, id: WinRT_String) -> win32more.Windows.Management.Setup.DeploymentWorkload: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Management.Setup.IDeploymentWorkload) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayFriendlyName(self: win32more.Windows.Management.Setup.IDeploymentWorkload) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayFriendlyName(self: win32more.Windows.Management.Setup.IDeploymentWorkload, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_StartTime(self: win32more.Windows.Management.Setup.IDeploymentWorkload) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def put_StartTime(self: win32more.Windows.Management.Setup.IDeploymentWorkload, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_mixinmethod
    def get_EndTime(self: win32more.Windows.Management.Setup.IDeploymentWorkload) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def put_EndTime(self: win32more.Windows.Management.Setup.IDeploymentWorkload, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorCode(self: win32more.Windows.Management.Setup.IDeploymentWorkload) -> UInt32: ...
    @winrt_mixinmethod
    def put_ErrorCode(self: win32more.Windows.Management.Setup.IDeploymentWorkload, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorMessage(self: win32more.Windows.Management.Setup.IDeploymentWorkload) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ErrorMessage(self: win32more.Windows.Management.Setup.IDeploymentWorkload, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PossibleCause(self: win32more.Windows.Management.Setup.IDeploymentWorkload) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PossibleCause(self: win32more.Windows.Management.Setup.IDeploymentWorkload, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PossibleResolution(self: win32more.Windows.Management.Setup.IDeploymentWorkload) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PossibleResolution(self: win32more.Windows.Management.Setup.IDeploymentWorkload, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Management.Setup.IDeploymentWorkload) -> win32more.Windows.Management.Setup.DeploymentWorkloadState: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Management.Setup.IDeploymentWorkload, value: win32more.Windows.Management.Setup.DeploymentWorkloadState) -> Void: ...
    @winrt_mixinmethod
    def get_StateDetails(self: win32more.Windows.Management.Setup.IDeploymentWorkload) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_StateDetails(self: win32more.Windows.Management.Setup.IDeploymentWorkload, value: WinRT_String) -> Void: ...
    DisplayFriendlyName = property(get_DisplayFriendlyName, put_DisplayFriendlyName)
    EndTime = property(get_EndTime, put_EndTime)
    ErrorCode = property(get_ErrorCode, put_ErrorCode)
    ErrorMessage = property(get_ErrorMessage, put_ErrorMessage)
    Id = property(get_Id, None)
    PossibleCause = property(get_PossibleCause, put_PossibleCause)
    PossibleResolution = property(get_PossibleResolution, put_PossibleResolution)
    StartTime = property(get_StartTime, put_StartTime)
    State = property(get_State, put_State)
    StateDetails = property(get_StateDetails, put_StateDetails)
class DeploymentWorkloadBatch(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Management.Setup.IDeploymentWorkloadBatch
    _classid_ = 'Windows.Management.Setup.DeploymentWorkloadBatch'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Management.Setup.DeploymentWorkloadBatch.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.Management.Setup.IDeploymentWorkloadBatchFactory, id: UInt32) -> win32more.Windows.Management.Setup.DeploymentWorkloadBatch: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Management.Setup.IDeploymentWorkloadBatch) -> UInt32: ...
    @winrt_mixinmethod
    def get_DisplayCategoryTitle(self: win32more.Windows.Management.Setup.IDeploymentWorkloadBatch) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayCategoryTitle(self: win32more.Windows.Management.Setup.IDeploymentWorkloadBatch, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_BatchWorkloads(self: win32more.Windows.Management.Setup.IDeploymentWorkloadBatch) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Management.Setup.DeploymentWorkload]: ...
    BatchWorkloads = property(get_BatchWorkloads, None)
    DisplayCategoryTitle = property(get_DisplayCategoryTitle, put_DisplayCategoryTitle)
    Id = property(get_Id, None)
class DeploymentWorkloadState(Enum, Int32):
    NotStarted = 0
    InProgress = 1
    Completed = 2
    Failed = 3
    Canceled = 4
    Skipped = 5
    Uninstalled = 6
    RebootRequired = 7
class DevicePreparationExecutionContext(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Management.Setup.IDevicePreparationExecutionContext
    _classid_ = 'Windows.Management.Setup.DevicePreparationExecutionContext'
    @winrt_mixinmethod
    def get_Context(self: win32more.Windows.Management.Setup.IDevicePreparationExecutionContext) -> WinRT_String: ...
    Context = property(get_Context, None)
class IAgentProvisioningProgressReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IAgentProvisioningProgressReport'
    _iid_ = Guid('{5097398a-70cc-5181-a7af-d31c167323d1}')
    @winrt_commethod(6)
    def get_State(self) -> win32more.Windows.Management.Setup.DeploymentAgentProgressState: ...
    @winrt_commethod(7)
    def put_State(self, value: win32more.Windows.Management.Setup.DeploymentAgentProgressState) -> Void: ...
    @winrt_commethod(8)
    def get_ProgressPercentage(self) -> Double: ...
    @winrt_commethod(9)
    def put_ProgressPercentage(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_EstimatedTimeRemaining(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(11)
    def put_EstimatedTimeRemaining(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(12)
    def get_DisplayProgress(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_DisplayProgress(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_DisplayProgressSecondary(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_DisplayProgressSecondary(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def get_Batches(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Management.Setup.DeploymentWorkloadBatch]: ...
    @winrt_commethod(17)
    def get_CurrentBatchIndex(self) -> UInt32: ...
    @winrt_commethod(18)
    def put_CurrentBatchIndex(self, value: UInt32) -> Void: ...
    Batches = property(get_Batches, None)
    CurrentBatchIndex = property(get_CurrentBatchIndex, put_CurrentBatchIndex)
    DisplayProgress = property(get_DisplayProgress, put_DisplayProgress)
    DisplayProgressSecondary = property(get_DisplayProgressSecondary, put_DisplayProgressSecondary)
    EstimatedTimeRemaining = property(get_EstimatedTimeRemaining, put_EstimatedTimeRemaining)
    ProgressPercentage = property(get_ProgressPercentage, put_ProgressPercentage)
    State = property(get_State, put_State)
class IDeploymentSessionConnectionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IDeploymentSessionConnectionChangedEventArgs'
    _iid_ = Guid('{8d40c631-6e4b-5d59-92f8-0de54c2a3c6b}')
    @winrt_commethod(6)
    def get_SessionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Change(self) -> win32more.Windows.Management.Setup.DeploymentSessionConnectionChange: ...
    Change = property(get_Change, None)
    SessionId = property(get_SessionId, None)
class IDeploymentSessionHeartbeatRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IDeploymentSessionHeartbeatRequestedEventArgs'
    _iid_ = Guid('{09d81fa0-1036-58e6-b63b-fe343c45005f}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class IDeploymentSessionStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IDeploymentSessionStateChangedEventArgs'
    _iid_ = Guid('{fbd3b7f3-88cb-5703-b8a5-0218de8fed81}')
    @winrt_commethod(6)
    def get_SessionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Change(self) -> win32more.Windows.Management.Setup.DeploymentSessionStateChange: ...
    Change = property(get_Change, None)
    SessionId = property(get_SessionId, None)
class IDeploymentWorkload(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IDeploymentWorkload'
    _iid_ = Guid('{1cefd3d4-456c-50d1-9312-cc5c818fc12e}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_DisplayFriendlyName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_DisplayFriendlyName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_StartTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(10)
    def put_StartTime(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_commethod(11)
    def get_EndTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(12)
    def put_EndTime(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_commethod(13)
    def get_ErrorCode(self) -> UInt32: ...
    @winrt_commethod(14)
    def put_ErrorCode(self, value: UInt32) -> Void: ...
    @winrt_commethod(15)
    def get_ErrorMessage(self) -> WinRT_String: ...
    @winrt_commethod(16)
    def put_ErrorMessage(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(17)
    def get_PossibleCause(self) -> WinRT_String: ...
    @winrt_commethod(18)
    def put_PossibleCause(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(19)
    def get_PossibleResolution(self) -> WinRT_String: ...
    @winrt_commethod(20)
    def put_PossibleResolution(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(21)
    def get_State(self) -> win32more.Windows.Management.Setup.DeploymentWorkloadState: ...
    @winrt_commethod(22)
    def put_State(self, value: win32more.Windows.Management.Setup.DeploymentWorkloadState) -> Void: ...
    @winrt_commethod(23)
    def get_StateDetails(self) -> WinRT_String: ...
    @winrt_commethod(24)
    def put_StateDetails(self, value: WinRT_String) -> Void: ...
    DisplayFriendlyName = property(get_DisplayFriendlyName, put_DisplayFriendlyName)
    EndTime = property(get_EndTime, put_EndTime)
    ErrorCode = property(get_ErrorCode, put_ErrorCode)
    ErrorMessage = property(get_ErrorMessage, put_ErrorMessage)
    Id = property(get_Id, None)
    PossibleCause = property(get_PossibleCause, put_PossibleCause)
    PossibleResolution = property(get_PossibleResolution, put_PossibleResolution)
    StartTime = property(get_StartTime, put_StartTime)
    State = property(get_State, put_State)
    StateDetails = property(get_StateDetails, put_StateDetails)
class IDeploymentWorkloadBatch(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IDeploymentWorkloadBatch'
    _iid_ = Guid('{5e56e3df-b9c0-5fee-ba3f-e89d800a9bf2}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_DisplayCategoryTitle(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_DisplayCategoryTitle(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_BatchWorkloads(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Management.Setup.DeploymentWorkload]: ...
    BatchWorkloads = property(get_BatchWorkloads, None)
    DisplayCategoryTitle = property(get_DisplayCategoryTitle, put_DisplayCategoryTitle)
    Id = property(get_Id, None)
class IDeploymentWorkloadBatchFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IDeploymentWorkloadBatchFactory'
    _iid_ = Guid('{d0209697-9560-5a05-bdf6-f1af535cb0d4}')
    @winrt_commethod(6)
    def CreateInstance(self, id: UInt32) -> win32more.Windows.Management.Setup.DeploymentWorkloadBatch: ...
class IDeploymentWorkloadFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IDeploymentWorkloadFactory'
    _iid_ = Guid('{41426c72-22a3-5339-bdf1-51268169aa61}')
    @winrt_commethod(6)
    def CreateInstance(self, id: WinRT_String) -> win32more.Windows.Management.Setup.DeploymentWorkload: ...
class IDevicePreparationExecutionContext(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IDevicePreparationExecutionContext'
    _iid_ = Guid('{084f221b-2484-5e81-a4e7-83f6caf19dc4}')
    @winrt_commethod(6)
    def get_Context(self) -> WinRT_String: ...
    Context = property(get_Context, None)
class IMachineProvisioningProgressReporter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IMachineProvisioningProgressReporter'
    _iid_ = Guid('{ebd8677f-dfd2-59da-ac3d-753ee1667cbb}')
    @winrt_commethod(6)
    def get_SessionId(self) -> Guid: ...
    @winrt_commethod(7)
    def get_SessionConnection(self) -> win32more.Windows.Management.Setup.DeploymentSessionConnectionChange: ...
    @winrt_commethod(8)
    def get_SessionState(self) -> win32more.Windows.Management.Setup.DeploymentSessionStateChange: ...
    @winrt_commethod(9)
    def add_SessionStateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Management.Setup.MachineProvisioningProgressReporter, win32more.Windows.Management.Setup.DeploymentSessionStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_SessionStateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_SessionConnectionChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Management.Setup.MachineProvisioningProgressReporter, win32more.Windows.Management.Setup.DeploymentSessionConnectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_SessionConnectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def ReportProgress(self, updateReport: win32more.Windows.Management.Setup.AgentProvisioningProgressReport) -> Void: ...
    @winrt_commethod(14)
    def GetDevicePreparationExecutionContextAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Management.Setup.DevicePreparationExecutionContext]: ...
    SessionConnection = property(get_SessionConnection, None)
    SessionId = property(get_SessionId, None)
    SessionState = property(get_SessionState, None)
    SessionStateChanged = event()
    SessionConnectionChanged = event()
class IMachineProvisioningProgressReporterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Setup.IMachineProvisioningProgressReporterStatics'
    _iid_ = Guid('{77682c17-5da3-51fc-a042-c7b53458ddb5}')
    @winrt_commethod(6)
    def GetForLaunchUri(self, launchUri: win32more.Windows.Foundation.Uri, heartbeatHandler: win32more.Windows.Management.Setup.DeploymentSessionHeartbeatRequested) -> win32more.Windows.Management.Setup.MachineProvisioningProgressReporter: ...
class MachineProvisioningProgressReporter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporter
    _classid_ = 'Windows.Management.Setup.MachineProvisioningProgressReporter'
    @winrt_mixinmethod
    def get_SessionId(self: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporter) -> Guid: ...
    @winrt_mixinmethod
    def get_SessionConnection(self: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporter) -> win32more.Windows.Management.Setup.DeploymentSessionConnectionChange: ...
    @winrt_mixinmethod
    def get_SessionState(self: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporter) -> win32more.Windows.Management.Setup.DeploymentSessionStateChange: ...
    @winrt_mixinmethod
    def add_SessionStateChanged(self: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporter, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Management.Setup.MachineProvisioningProgressReporter, win32more.Windows.Management.Setup.DeploymentSessionStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SessionStateChanged(self: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporter, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SessionConnectionChanged(self: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporter, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Management.Setup.MachineProvisioningProgressReporter, win32more.Windows.Management.Setup.DeploymentSessionConnectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SessionConnectionChanged(self: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporter, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ReportProgress(self: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporter, updateReport: win32more.Windows.Management.Setup.AgentProvisioningProgressReport) -> Void: ...
    @winrt_mixinmethod
    def GetDevicePreparationExecutionContextAsync(self: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporter) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Management.Setup.DevicePreparationExecutionContext]: ...
    @winrt_classmethod
    def GetForLaunchUri(cls: win32more.Windows.Management.Setup.IMachineProvisioningProgressReporterStatics, launchUri: win32more.Windows.Foundation.Uri, heartbeatHandler: win32more.Windows.Management.Setup.DeploymentSessionHeartbeatRequested) -> win32more.Windows.Management.Setup.MachineProvisioningProgressReporter: ...
    SessionConnection = property(get_SessionConnection, None)
    SessionId = property(get_SessionId, None)
    SessionState = property(get_SessionState, None)
    SessionStateChanged = event()
    SessionConnectionChanged = event()


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.TpmBaseServices
TBS_CONTEXT_VERSION_ONE: UInt32 = 1
TBS_SUCCESS: UInt32 = 0
TBS_OWNERAUTH_TYPE_FULL: UInt32 = 1
TBS_OWNERAUTH_TYPE_ADMIN: UInt32 = 2
TBS_OWNERAUTH_TYPE_USER: UInt32 = 3
TBS_OWNERAUTH_TYPE_ENDORSEMENT: UInt32 = 4
TBS_OWNERAUTH_TYPE_ENDORSEMENT_20: UInt32 = 12
TBS_OWNERAUTH_TYPE_STORAGE_20: UInt32 = 13
TBS_CONTEXT_VERSION_TWO: UInt32 = 2
TPM_WNF_INFO_CLEAR_SUCCESSFUL: UInt32 = 1
TPM_WNF_INFO_OWNERSHIP_SUCCESSFUL: UInt32 = 2
TPM_WNF_INFO_NO_REBOOT_REQUIRED: UInt32 = 1
TPM_VERSION_UNKNOWN: UInt32 = 0
TPM_VERSION_12: UInt32 = 1
TPM_VERSION_20: UInt32 = 2
TPM_IFTYPE_UNKNOWN: UInt32 = 0
TPM_IFTYPE_1: UInt32 = 1
TPM_IFTYPE_TRUSTZONE: UInt32 = 2
TPM_IFTYPE_HW: UInt32 = 3
TPM_IFTYPE_EMULATOR: UInt32 = 4
TPM_IFTYPE_SPB: UInt32 = 5
TBS_TCGLOG_SRTM_CURRENT: UInt32 = 0
TBS_TCGLOG_DRTM_CURRENT: UInt32 = 1
TBS_TCGLOG_SRTM_BOOT: UInt32 = 2
TBS_TCGLOG_SRTM_RESUME: UInt32 = 3
TBS_TCGLOG_DRTM_BOOT: UInt32 = 4
TBS_TCGLOG_DRTM_RESUME: UInt32 = 5
@winfunctype('tbs.dll')
def Tbsi_Context_Create(pContextParams: POINTER(win32more.Windows.Win32.System.TpmBaseServices.TBS_CONTEXT_PARAMS), phContext: POINTER(VoidPtr)) -> UInt32: ...
@winfunctype('tbs.dll')
def Tbsip_Context_Close(hContext: VoidPtr) -> UInt32: ...
@winfunctype('tbs.dll')
def Tbsip_Submit_Command(hContext: VoidPtr, Locality: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_LOCALITY, Priority: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_PRIORITY, pabCommand: POINTER(Byte), cbCommand: UInt32, pabResult: POINTER(Byte), pcbResult: POINTER(UInt32)) -> UInt32: ...
@winfunctype('tbs.dll')
def Tbsip_Cancel_Commands(hContext: VoidPtr) -> UInt32: ...
@winfunctype('tbs.dll')
def Tbsi_Physical_Presence_Command(hContext: VoidPtr, pabInput: POINTER(Byte), cbInput: UInt32, pabOutput: POINTER(Byte), pcbOutput: POINTER(UInt32)) -> UInt32: ...
@winfunctype('tbs.dll')
def Tbsi_Get_TCG_Log(hContext: VoidPtr, pOutputBuf: POINTER(Byte), pOutputBufLen: POINTER(UInt32)) -> UInt32: ...
@winfunctype('tbs.dll')
def Tbsi_GetDeviceInfo(Size: UInt32, Info: VoidPtr) -> UInt32: ...
@winfunctype('tbs.dll')
def Tbsi_Get_OwnerAuth(hContext: VoidPtr, ownerauthType: UInt32, pOutputBuf: POINTER(Byte), pOutputBufLen: POINTER(UInt32)) -> UInt32: ...
@winfunctype('tbs.dll')
def Tbsi_Revoke_Attestation() -> UInt32: ...
@winfunctype('tbs.dll')
def GetDeviceID(pbWindowsAIK: POINTER(Byte), cbWindowsAIK: UInt32, pcbResult: POINTER(UInt32), pfProtectedByTPM: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('tbs.dll')
def GetDeviceIDString(pszWindowsAIK: win32more.Windows.Win32.Foundation.PWSTR, cchWindowsAIK: UInt32, pcchResult: POINTER(UInt32), pfProtectedByTPM: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('tbs.dll')
def Tbsi_Create_Windows_Key(keyHandle: UInt32) -> UInt32: ...
@winfunctype('tbs.dll')
def Tbsi_Get_TCG_Log_Ex(logType: UInt32, pbOutput: POINTER(Byte), pcbOutput: POINTER(UInt32)) -> UInt32: ...
@winfunctype('tbs.dll')
def Tbsi_Is_Tpm_Present() -> win32more.Windows.Win32.Foundation.BOOL: ...
TBS_COMMAND_LOCALITY = UInt32
TBS_COMMAND_LOCALITY_ZERO: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_LOCALITY = 0
TBS_COMMAND_LOCALITY_ONE: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_LOCALITY = 1
TBS_COMMAND_LOCALITY_TWO: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_LOCALITY = 2
TBS_COMMAND_LOCALITY_THREE: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_LOCALITY = 3
TBS_COMMAND_LOCALITY_FOUR: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_LOCALITY = 4
TBS_COMMAND_PRIORITY = UInt32
TBS_COMMAND_PRIORITY_LOW: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_PRIORITY = 100
TBS_COMMAND_PRIORITY_NORMAL: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_PRIORITY = 200
TBS_COMMAND_PRIORITY_SYSTEM: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_PRIORITY = 400
TBS_COMMAND_PRIORITY_HIGH: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_PRIORITY = 300
TBS_COMMAND_PRIORITY_MAX: win32more.Windows.Win32.System.TpmBaseServices.TBS_COMMAND_PRIORITY = 2147483648
class TBS_CONTEXT_PARAMS(Structure):
    version: UInt32
class TBS_CONTEXT_PARAMS2(Structure):
    version: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        asUINT32: UInt32
        class _Anonymous_e__Struct(Structure):
            requestRaw: Annotated[UInt32, 1]
            includeTpm12: Annotated[UInt32, 1]
            includeTpm20: Annotated[UInt32, 1]
class TPM_DEVICE_INFO(Structure):
    structVersion: UInt32
    tpmVersion: UInt32
    tpmInterfaceType: UInt32
    tpmImpRevision: UInt32
class TPM_WNF_PROVISIONING(Structure):
    status: UInt32
    message: Byte * 28


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.System.Diagnostics.TraceLogging
WINEVENT_CHANNEL_CLASSIC_TRACE: Int32 = 0
WINEVENT_CHANNEL_GLOBAL_SYSTEM: Int32 = 8
WINEVENT_CHANNEL_GLOBAL_APPLICATION: Int32 = 9
WINEVENT_CHANNEL_GLOBAL_SECURITY: Int32 = 10
WINEVENT_CHANNEL_TRACELOGGING: Int32 = 11
WINEVENT_CHANNEL_PROVIDERMETADATA: Int32 = 12
WINEVENT_LEVEL_LOG_ALWAYS: Int32 = 0
WINEVENT_LEVEL_CRITICAL: Int32 = 1
WINEVENT_LEVEL_ERROR: Int32 = 2
WINEVENT_LEVEL_WARNING: Int32 = 3
WINEVENT_LEVEL_INFO: Int32 = 4
WINEVENT_LEVEL_VERBOSE: Int32 = 5
WINEVENT_LEVEL_RESERVED_6: Int32 = 6
WINEVENT_LEVEL_RESERVED_7: Int32 = 7
WINEVENT_LEVEL_RESERVED_8: Int32 = 8
WINEVENT_LEVEL_RESERVED_9: Int32 = 9
WINEVENT_LEVEL_RESERVED_10: Int32 = 10
WINEVENT_LEVEL_RESERVED_11: Int32 = 11
WINEVENT_LEVEL_RESERVED_12: Int32 = 12
WINEVENT_LEVEL_RESERVED_13: Int32 = 13
WINEVENT_LEVEL_RESERVED_14: Int32 = 14
WINEVENT_LEVEL_RESERVED_15: Int32 = 15
WINEVENT_OPCODE_INFO: Int32 = 0
WINEVENT_OPCODE_START: Int32 = 1
WINEVENT_OPCODE_STOP: Int32 = 2
WINEVENT_OPCODE_DC_START: Int32 = 3
WINEVENT_OPCODE_DC_STOP: Int32 = 4
WINEVENT_OPCODE_EXTENSION: Int32 = 5
WINEVENT_OPCODE_REPLY: Int32 = 6
WINEVENT_OPCODE_RESUME: Int32 = 7
WINEVENT_OPCODE_SUSPEND: Int32 = 8
WINEVENT_OPCODE_SEND: Int32 = 9
WINEVENT_OPCODE_RECEIVE: Int32 = 240
WINEVENT_OPCODE_RESERVED_241: Int32 = 241
WINEVENT_OPCODE_RESERVED_242: Int32 = 242
WINEVENT_OPCODE_RESERVED_243: Int32 = 243
WINEVENT_OPCODE_RESERVED_244: Int32 = 244
WINEVENT_OPCODE_RESERVED_245: Int32 = 245
WINEVENT_OPCODE_RESERVED_246: Int32 = 246
WINEVENT_OPCODE_RESERVED_247: Int32 = 247
WINEVENT_OPCODE_RESERVED_248: Int32 = 248
WINEVENT_OPCODE_RESERVED_249: Int32 = 249
WINEVENT_OPCODE_RESERVED_250: Int32 = 250
WINEVENT_OPCODE_RESERVED_251: Int32 = 251
WINEVENT_OPCODE_RESERVED_252: Int32 = 252
WINEVENT_OPCODE_RESERVED_253: Int32 = 253
WINEVENT_OPCODE_RESERVED_254: Int32 = 254
WINEVENT_OPCODE_RESERVED_255: Int32 = 255
WINEVENT_TASK_NONE: Int32 = 0
WINEVT_KEYWORD_ANY: Int32 = 0
WINEVENT_KEYWORD_RESPONSE_TIME: Int64 = 281474976710656
WINEVENT_KEYWORD_RESERVED_49: Int64 = 562949953421312
WINEVENT_KEYWORD_WDI_DIAG: Int64 = 1125899906842624
WINEVENT_KEYWORD_SQM: Int64 = 2251799813685248
WINEVENT_KEYWORD_AUDIT_FAILURE: Int64 = 4503599627370496
WINEVENT_KEYWORD_AUDIT_SUCCESS: Int64 = 9007199254740992
WINEVENT_KEYWORD_CORRELATION_HINT: Int64 = 18014398509481984
WINEVENT_KEYWORD_EVENTLOG_CLASSIC: Int64 = 36028797018963968
WINEVENT_KEYWORD_RESERVED_56: Int64 = 72057594037927936
WINEVENT_KEYWORD_RESERVED_57: Int64 = 144115188075855872
WINEVENT_KEYWORD_RESERVED_58: Int64 = 288230376151711744
WINEVENT_KEYWORD_RESERVED_59: Int64 = 576460752303423488
WINEVENT_KEYWORD_RESERVED_60: Int64 = 1152921504606846976
WINEVENT_KEYWORD_RESERVED_61: Int64 = 2305843009213693952
WINEVENT_KEYWORD_RESERVED_62: Int64 = 4611686018427387904
WINEVENT_KEYWORD_RESERVED_63: UInt64 = 9223372036854775808
MSG_category_Devices: Int32 = 1
MSG_category_Disk: Int32 = 2
MSG_category_Network: Int32 = 7
MSG_category_Printers: Int32 = 3
MSG_category_Services: Int32 = 4
MSG_category_Shell: Int32 = 5
MSG_category_SystemEvent: Int32 = 6
MSG_channel_Application: Int32 = 256
MSG_channel_ProviderMetadata: Int32 = -1879048189
MSG_channel_Security: Int32 = 257
MSG_channel_System: Int32 = 258
MSG_channel_TraceClassic: Int32 = -1879048191
MSG_channel_TraceLogging: Int32 = -1879048190
MSG_keyword_AnyKeyword: Int32 = 268435456
MSG_keyword_AuditFailure: Int32 = 268435509
MSG_keyword_AuditSuccess: Int32 = 268435510
MSG_keyword_Classic: Int32 = 268435512
MSG_keyword_CorrelationHint: Int32 = 268435511
MSG_keyword_ResponseTime: Int32 = 268435505
MSG_keyword_SQM: Int32 = 268435508
MSG_keyword_WDIDiag: Int32 = 268435507
MSG_level_Critical: Int32 = 1342177281
MSG_level_Error: Int32 = 1342177282
MSG_level_Informational: Int32 = 1342177284
MSG_level_LogAlways: Int32 = 1342177280
MSG_level_Verbose: Int32 = 1342177285
MSG_level_Warning: Int32 = 1342177283
MSG_opcode_DCStart: Int32 = 805502976
MSG_opcode_DCStop: Int32 = 805568512
MSG_opcode_Extension: Int32 = 805634048
MSG_opcode_Info: Int32 = 805306368
MSG_opcode_Receive: Int32 = 821035008
MSG_opcode_Reply: Int32 = 805699584
MSG_opcode_Resume: Int32 = 805765120
MSG_opcode_Send: Int32 = 805896192
MSG_opcode_Start: Int32 = 805371904
MSG_opcode_Stop: Int32 = 805437440
MSG_opcode_Suspend: Int32 = 805830656
MSG_task_None: Int32 = 1879048192


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Gaming.Preview.GamesEnumeration
import win32more.Windows.Storage
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class GameList(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.GameList'
    @winrt_classmethod
    def MergeEntriesAsync(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListStatics2, left: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry, right: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry]: ...
    @winrt_classmethod
    def UnmergeEntryAsync(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListStatics2, mergedEntry: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry]]: ...
    @winrt_classmethod
    def FindAllAsync(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry]]: ...
    @winrt_classmethod
    def FindAllAsyncPackageFamilyName(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListStatics, packageFamilyName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry]]: ...
    @winrt_classmethod
    def add_GameAdded(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListStatics, handler: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_GameAdded(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_GameRemoved(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListStatics, handler: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListRemovedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_GameRemoved(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_GameUpdated(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListStatics, handler: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_GameUpdated(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
class GameListCategory(Enum, Int32):
    Candidate = 0
    ConfirmedBySystem = 1
    ConfirmedByUser = 2
class GameListChangedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{25f6a421-d8f5-4d91-b40e-53d5e86fde64}')
    @winrt_commethod(3)
    def Invoke(self, game: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry) -> Void: ...
class GameListEntry(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.GameListEntry'
    @winrt_mixinmethod
    def get_DisplayInfo(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry) -> win32more.Windows.ApplicationModel.AppDisplayInfo: ...
    @winrt_mixinmethod
    def LaunchAsync(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def get_Category(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry) -> win32more.Windows.Gaming.Preview.GamesEnumeration.GameListCategory: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def SetCategoryAsync(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry, value: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListCategory) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def get_LaunchableState(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry2) -> win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntryLaunchableState: ...
    @winrt_mixinmethod
    def get_LauncherExecutable(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry2) -> win32more.Windows.Storage.IStorageFile: ...
    @winrt_mixinmethod
    def get_LaunchParameters(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry2) -> WinRT_String: ...
    @winrt_mixinmethod
    def SetLauncherExecutableFileAsync(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry2, executableFile: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def SetLauncherExecutableFileWithParamsAsync(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry2, executableFile: win32more.Windows.Storage.IStorageFile, launchParams: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def get_TitleId(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry2) -> WinRT_String: ...
    @winrt_mixinmethod
    def SetTitleIdAsync(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry2, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def get_GameModeConfiguration(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameListEntry2) -> win32more.Windows.Gaming.Preview.GamesEnumeration.GameModeConfiguration: ...
    Category = property(get_Category, None)
    DisplayInfo = property(get_DisplayInfo, None)
    GameModeConfiguration = property(get_GameModeConfiguration, None)
    LaunchParameters = property(get_LaunchParameters, None)
    LaunchableState = property(get_LaunchableState, None)
    LauncherExecutable = property(get_LauncherExecutable, None)
    Properties = property(get_Properties, None)
    TitleId = property(get_TitleId, None)
class GameListEntryLaunchableState(Enum, Int32):
    NotLaunchable = 0
    ByLastRunningFullPath = 1
    ByUserProvidedPath = 2
    ByTile = 3
class GameListRemovedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{10c5648f-6c8f-4712-9b38-474bc22e76d8}')
    @winrt_commethod(3)
    def Invoke(self, identifier: WinRT_String) -> Void: ...
class GameModeConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.GameModeConfiguration'
    @winrt_mixinmethod
    def get_IsEnabled(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsEnabled(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_RelatedProcessNames(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def get_PercentGpuTimeAllocatedToGame(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_mixinmethod
    def put_PercentGpuTimeAllocatedToGame(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_mixinmethod
    def get_PercentGpuMemoryAllocatedToGame(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_mixinmethod
    def put_PercentGpuMemoryAllocatedToGame(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_mixinmethod
    def get_PercentGpuMemoryAllocatedToSystemCompositor(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_mixinmethod
    def put_PercentGpuMemoryAllocatedToSystemCompositor(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_mixinmethod
    def get_MaxCpuCount(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_mixinmethod
    def put_MaxCpuCount(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_mixinmethod
    def get_CpuExclusivityMaskLow(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_mixinmethod
    def put_CpuExclusivityMaskLow(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_mixinmethod
    def get_CpuExclusivityMaskHigh(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_mixinmethod
    def put_CpuExclusivityMaskHigh(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_mixinmethod
    def get_AffinitizeToExclusiveCpus(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def put_AffinitizeToExclusiveCpus(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def SaveAsync(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration) -> win32more.Windows.Foundation.IAsyncAction: ...
    AffinitizeToExclusiveCpus = property(get_AffinitizeToExclusiveCpus, put_AffinitizeToExclusiveCpus)
    CpuExclusivityMaskHigh = property(get_CpuExclusivityMaskHigh, put_CpuExclusivityMaskHigh)
    CpuExclusivityMaskLow = property(get_CpuExclusivityMaskLow, put_CpuExclusivityMaskLow)
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    MaxCpuCount = property(get_MaxCpuCount, put_MaxCpuCount)
    PercentGpuMemoryAllocatedToGame = property(get_PercentGpuMemoryAllocatedToGame, put_PercentGpuMemoryAllocatedToGame)
    PercentGpuMemoryAllocatedToSystemCompositor = property(get_PercentGpuMemoryAllocatedToSystemCompositor, put_PercentGpuMemoryAllocatedToSystemCompositor)
    PercentGpuTimeAllocatedToGame = property(get_PercentGpuTimeAllocatedToGame, put_PercentGpuTimeAllocatedToGame)
    RelatedProcessNames = property(get_RelatedProcessNames, None)
class GameModeUserConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeUserConfiguration
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.GameModeUserConfiguration'
    @winrt_mixinmethod
    def get_GamingRelatedProcessNames(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeUserConfiguration) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def SaveAsync(self: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeUserConfiguration) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Windows.Gaming.Preview.GamesEnumeration.IGameModeUserConfigurationStatics) -> win32more.Windows.Gaming.Preview.GamesEnumeration.GameModeUserConfiguration: ...
    GamingRelatedProcessNames = property(get_GamingRelatedProcessNames, None)
class IGameListEntry(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.IGameListEntry'
    _iid_ = Guid('{735924d3-811f-4494-b69c-c641a0c61543}')
    @winrt_commethod(6)
    def get_DisplayInfo(self) -> win32more.Windows.ApplicationModel.AppDisplayInfo: ...
    @winrt_commethod(7)
    def LaunchAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(8)
    def get_Category(self) -> win32more.Windows.Gaming.Preview.GamesEnumeration.GameListCategory: ...
    @winrt_commethod(9)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(10)
    def SetCategoryAsync(self, value: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListCategory) -> win32more.Windows.Foundation.IAsyncAction: ...
    Category = property(get_Category, None)
    DisplayInfo = property(get_DisplayInfo, None)
    Properties = property(get_Properties, None)
class IGameListEntry2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.IGameListEntry2'
    _iid_ = Guid('{d84a8f8b-8749-4a25-90d3-f6c5a427886d}')
    @winrt_commethod(6)
    def get_LaunchableState(self) -> win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntryLaunchableState: ...
    @winrt_commethod(7)
    def get_LauncherExecutable(self) -> win32more.Windows.Storage.IStorageFile: ...
    @winrt_commethod(8)
    def get_LaunchParameters(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def SetLauncherExecutableFileAsync(self, executableFile: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(10)
    def SetLauncherExecutableFileWithParamsAsync(self, executableFile: win32more.Windows.Storage.IStorageFile, launchParams: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(11)
    def get_TitleId(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def SetTitleIdAsync(self, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(13)
    def get_GameModeConfiguration(self) -> win32more.Windows.Gaming.Preview.GamesEnumeration.GameModeConfiguration: ...
    GameModeConfiguration = property(get_GameModeConfiguration, None)
    LaunchParameters = property(get_LaunchParameters, None)
    LaunchableState = property(get_LaunchableState, None)
    LauncherExecutable = property(get_LauncherExecutable, None)
    TitleId = property(get_TitleId, None)
class IGameListStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.IGameListStatics'
    _iid_ = Guid('{2ddd0f6f-9c66-4b05-945c-d6ed78491b8c}')
    @winrt_commethod(6)
    def FindAllAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry]]: ...
    @winrt_commethod(7)
    def FindAllAsyncPackageFamilyName(self, packageFamilyName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry]]: ...
    @winrt_commethod(8)
    def add_GameAdded(self, handler: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_GameAdded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_GameRemoved(self, handler: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListRemovedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_GameRemoved(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_GameUpdated(self, handler: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_GameUpdated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    GameAdded = event()
    GameRemoved = event()
    GameUpdated = event()
class IGameListStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.IGameListStatics2'
    _iid_ = Guid('{395f2098-ea1a-45aa-9268-a83905686f27}')
    @winrt_commethod(6)
    def MergeEntriesAsync(self, left: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry, right: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry]: ...
    @winrt_commethod(7)
    def UnmergeEntryAsync(self, mergedEntry: win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Preview.GamesEnumeration.GameListEntry]]: ...
class IGameModeConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.IGameModeConfiguration'
    _iid_ = Guid('{78e591af-b142-4ef0-8830-55bc2be4f5ea}')
    @winrt_commethod(6)
    def get_IsEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_RelatedProcessNames(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_commethod(9)
    def get_PercentGpuTimeAllocatedToGame(self) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_commethod(10)
    def put_PercentGpuTimeAllocatedToGame(self, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_commethod(11)
    def get_PercentGpuMemoryAllocatedToGame(self) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_commethod(12)
    def put_PercentGpuMemoryAllocatedToGame(self, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_commethod(13)
    def get_PercentGpuMemoryAllocatedToSystemCompositor(self) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_commethod(14)
    def put_PercentGpuMemoryAllocatedToSystemCompositor(self, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_commethod(15)
    def get_MaxCpuCount(self) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_commethod(16)
    def put_MaxCpuCount(self, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_commethod(17)
    def get_CpuExclusivityMaskLow(self) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_commethod(18)
    def put_CpuExclusivityMaskLow(self, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_commethod(19)
    def get_CpuExclusivityMaskHigh(self) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_commethod(20)
    def put_CpuExclusivityMaskHigh(self, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    @winrt_commethod(21)
    def get_AffinitizeToExclusiveCpus(self) -> Boolean: ...
    @winrt_commethod(22)
    def put_AffinitizeToExclusiveCpus(self, value: Boolean) -> Void: ...
    @winrt_commethod(23)
    def SaveAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    AffinitizeToExclusiveCpus = property(get_AffinitizeToExclusiveCpus, put_AffinitizeToExclusiveCpus)
    CpuExclusivityMaskHigh = property(get_CpuExclusivityMaskHigh, put_CpuExclusivityMaskHigh)
    CpuExclusivityMaskLow = property(get_CpuExclusivityMaskLow, put_CpuExclusivityMaskLow)
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    MaxCpuCount = property(get_MaxCpuCount, put_MaxCpuCount)
    PercentGpuMemoryAllocatedToGame = property(get_PercentGpuMemoryAllocatedToGame, put_PercentGpuMemoryAllocatedToGame)
    PercentGpuMemoryAllocatedToSystemCompositor = property(get_PercentGpuMemoryAllocatedToSystemCompositor, put_PercentGpuMemoryAllocatedToSystemCompositor)
    PercentGpuTimeAllocatedToGame = property(get_PercentGpuTimeAllocatedToGame, put_PercentGpuTimeAllocatedToGame)
    RelatedProcessNames = property(get_RelatedProcessNames, None)
class IGameModeUserConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.IGameModeUserConfiguration'
    _iid_ = Guid('{72d34af4-756b-470f-a0c2-ba62a90795db}')
    @winrt_commethod(6)
    def get_GamingRelatedProcessNames(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_commethod(7)
    def SaveAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    GamingRelatedProcessNames = property(get_GamingRelatedProcessNames, None)
class IGameModeUserConfigurationStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Preview.GamesEnumeration.IGameModeUserConfigurationStatics'
    _iid_ = Guid('{6e50d97c-66ea-478e-a4a1-f57c0e8d00e7}')
    @winrt_commethod(6)
    def GetDefault(self) -> win32more.Windows.Gaming.Preview.GamesEnumeration.GameModeUserConfiguration: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Antimalware
import win32more.Windows.Win32.System.Com
AMSI_ATTRIBUTE = Int32
AMSI_ATTRIBUTE_APP_NAME: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE = 0
AMSI_ATTRIBUTE_CONTENT_NAME: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE = 1
AMSI_ATTRIBUTE_CONTENT_SIZE: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE = 2
AMSI_ATTRIBUTE_CONTENT_ADDRESS: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE = 3
AMSI_ATTRIBUTE_SESSION: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE = 4
AMSI_ATTRIBUTE_REDIRECT_CHAIN_SIZE: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE = 5
AMSI_ATTRIBUTE_REDIRECT_CHAIN_ADDRESS: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE = 6
AMSI_ATTRIBUTE_ALL_SIZE: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE = 7
AMSI_ATTRIBUTE_ALL_ADDRESS: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE = 8
AMSI_ATTRIBUTE_QUIET: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE = 9
AMSI_RESULT = Int32
AMSI_RESULT_CLEAN: win32more.Windows.Win32.System.Antimalware.AMSI_RESULT = 0
AMSI_RESULT_NOT_DETECTED: win32more.Windows.Win32.System.Antimalware.AMSI_RESULT = 1
AMSI_RESULT_BLOCKED_BY_ADMIN_START: win32more.Windows.Win32.System.Antimalware.AMSI_RESULT = 16384
AMSI_RESULT_BLOCKED_BY_ADMIN_END: win32more.Windows.Win32.System.Antimalware.AMSI_RESULT = 20479
AMSI_RESULT_DETECTED: win32more.Windows.Win32.System.Antimalware.AMSI_RESULT = 32768
AMSI_UAC_MSI_ACTION = Int32
AMSI_UAC_MSI_ACTION_INSTALL: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_MSI_ACTION = 0
AMSI_UAC_MSI_ACTION_UNINSTALL: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_MSI_ACTION = 1
AMSI_UAC_MSI_ACTION_UPDATE: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_MSI_ACTION = 2
AMSI_UAC_MSI_ACTION_MAINTENANCE: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_MSI_ACTION = 3
AMSI_UAC_MSI_ACTION_MAX: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_MSI_ACTION = 4
class AMSI_UAC_REQUEST_AX_INFO(Structure):
    ulLength: UInt32
    lpwszLocalInstallPath: win32more.Windows.Win32.Foundation.PWSTR
    lpwszSourceURL: win32more.Windows.Win32.Foundation.PWSTR
class AMSI_UAC_REQUEST_COM_INFO(Structure):
    ulLength: UInt32
    lpwszServerBinary: win32more.Windows.Win32.Foundation.PWSTR
    lpwszRequestor: win32more.Windows.Win32.Foundation.PWSTR
    Clsid: Guid
class AMSI_UAC_REQUEST_CONTEXT(Structure):
    ulLength: UInt32
    ulRequestorProcessId: UInt32
    UACTrustState: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_TRUST_STATE
    Type: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_TYPE
    RequestType: _RequestType_e__Union
    bAutoElevateRequest: win32more.Windows.Win32.Foundation.BOOL
    class _RequestType_e__Union(Union):
        ExeInfo: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_EXE_INFO
        ComInfo: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_COM_INFO
        MsiInfo: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_MSI_INFO
        ActiveXInfo: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_AX_INFO
        PackagedAppInfo: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_PACKAGED_APP_INFO
class AMSI_UAC_REQUEST_EXE_INFO(Structure):
    ulLength: UInt32
    lpwszApplicationName: win32more.Windows.Win32.Foundation.PWSTR
    lpwszCommandLine: win32more.Windows.Win32.Foundation.PWSTR
    lpwszDLLParameter: win32more.Windows.Win32.Foundation.PWSTR
class AMSI_UAC_REQUEST_MSI_INFO(Structure):
    ulLength: UInt32
    MsiAction: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_MSI_ACTION
    lpwszProductName: win32more.Windows.Win32.Foundation.PWSTR
    lpwszVersion: win32more.Windows.Win32.Foundation.PWSTR
    lpwszLanguage: win32more.Windows.Win32.Foundation.PWSTR
    lpwszManufacturer: win32more.Windows.Win32.Foundation.PWSTR
    lpwszPackagePath: win32more.Windows.Win32.Foundation.PWSTR
    lpwszPackageSource: win32more.Windows.Win32.Foundation.PWSTR
    ulUpdates: UInt32
    ppwszUpdates: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
    ppwszUpdateSources: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
class AMSI_UAC_REQUEST_PACKAGED_APP_INFO(Structure):
    ulLength: UInt32
    lpwszApplicationName: win32more.Windows.Win32.Foundation.PWSTR
    lpwszCommandLine: win32more.Windows.Win32.Foundation.PWSTR
    lpPackageFamilyName: win32more.Windows.Win32.Foundation.PWSTR
    lpApplicationId: win32more.Windows.Win32.Foundation.PWSTR
AMSI_UAC_REQUEST_TYPE = Int32
AMSI_UAC_REQUEST_TYPE_EXE: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_TYPE = 0
AMSI_UAC_REQUEST_TYPE_COM: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_TYPE = 1
AMSI_UAC_REQUEST_TYPE_MSI: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_TYPE = 2
AMSI_UAC_REQUEST_TYPE_AX: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_TYPE = 3
AMSI_UAC_REQUEST_TYPE_PACKAGED_APP: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_TYPE = 4
AMSI_UAC_REQUEST_TYPE_MAX: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_TYPE = 5
AMSI_UAC_TRUST_STATE = Int32
AMSI_UAC_TRUST_STATE_TRUSTED: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_TRUST_STATE = 0
AMSI_UAC_TRUST_STATE_UNTRUSTED: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_TRUST_STATE = 1
AMSI_UAC_TRUST_STATE_BLOCKED: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_TRUST_STATE = 2
AMSI_UAC_TRUST_STATE_MAX: win32more.Windows.Win32.System.Antimalware.AMSI_UAC_TRUST_STATE = 3
@winfunctype('Amsi.dll')
def AmsiInitialize(appName: win32more.Windows.Win32.Foundation.PWSTR, amsiContext: POINTER(win32more.Windows.Win32.System.Antimalware.HAMSICONTEXT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('Amsi.dll')
def AmsiUninitialize(amsiContext: win32more.Windows.Win32.System.Antimalware.HAMSICONTEXT) -> Void: ...
@winfunctype('Amsi.dll')
def AmsiOpenSession(amsiContext: win32more.Windows.Win32.System.Antimalware.HAMSICONTEXT, amsiSession: POINTER(win32more.Windows.Win32.System.Antimalware.HAMSISESSION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('Amsi.dll')
def AmsiCloseSession(amsiContext: win32more.Windows.Win32.System.Antimalware.HAMSICONTEXT, amsiSession: win32more.Windows.Win32.System.Antimalware.HAMSISESSION) -> Void: ...
@winfunctype('Amsi.dll')
def AmsiScanBuffer(amsiContext: win32more.Windows.Win32.System.Antimalware.HAMSICONTEXT, buffer: VoidPtr, length: UInt32, contentName: win32more.Windows.Win32.Foundation.PWSTR, amsiSession: win32more.Windows.Win32.System.Antimalware.HAMSISESSION, result: POINTER(win32more.Windows.Win32.System.Antimalware.AMSI_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('Amsi.dll')
def AmsiNotifyOperation(amsiContext: win32more.Windows.Win32.System.Antimalware.HAMSICONTEXT, buffer: VoidPtr, length: UInt32, contentName: win32more.Windows.Win32.Foundation.PWSTR, result: POINTER(win32more.Windows.Win32.System.Antimalware.AMSI_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('Amsi.dll')
def AmsiScanString(amsiContext: win32more.Windows.Win32.System.Antimalware.HAMSICONTEXT, string: win32more.Windows.Win32.Foundation.PWSTR, contentName: win32more.Windows.Win32.Foundation.PWSTR, amsiSession: win32more.Windows.Win32.System.Antimalware.HAMSISESSION, result: POINTER(win32more.Windows.Win32.System.Antimalware.AMSI_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('KERNEL32.dll')
def InstallELAMCertificateInfo(ELAMFile: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
CAntimalware = Guid('{fdb00e52-a214-4aa1-8fba-4357bb0072ec}')
HAMSICONTEXT = VoidPtr
HAMSISESSION = VoidPtr
class IAmsiStream(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3e47f2e5-81d4-4d3b-897f-545096770373}')
    @commethod(3)
    def GetAttribute(self, attribute: win32more.Windows.Win32.System.Antimalware.AMSI_ATTRIBUTE, dataSize: UInt32, data: POINTER(Byte), retData: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Read(self, position: UInt64, size: UInt32, buffer: POINTER(Byte), readSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAntimalware(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{82d29c2e-f062-44e6-b5c9-3d9a2f24a2df}')
    @commethod(3)
    def Scan(self, stream: win32more.Windows.Win32.System.Antimalware.IAmsiStream, result: POINTER(win32more.Windows.Win32.System.Antimalware.AMSI_RESULT), provider: POINTER(win32more.Windows.Win32.System.Antimalware.IAntimalwareProvider)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CloseSession(self, session: UInt64) -> Void: ...
class IAntimalware2(ComPtr):
    extends: win32more.Windows.Win32.System.Antimalware.IAntimalware
    _iid_ = Guid('{301035b5-2d42-4f56-8c65-2dcaa7fb3cdc}')
    @commethod(5)
    def Notify(self, buffer: VoidPtr, length: UInt32, contentName: win32more.Windows.Win32.Foundation.PWSTR, appName: win32more.Windows.Win32.Foundation.PWSTR, pResult: POINTER(win32more.Windows.Win32.System.Antimalware.AMSI_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAntimalwareProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b2cabfe3-fe04-42b1-a5df-08d483d4d125}')
    @commethod(3)
    def Scan(self, stream: win32more.Windows.Win32.System.Antimalware.IAmsiStream, result: POINTER(win32more.Windows.Win32.System.Antimalware.AMSI_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CloseSession(self, session: UInt64) -> Void: ...
    @commethod(5)
    def DisplayName(self, displayName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAntimalwareProvider2(ComPtr):
    extends: win32more.Windows.Win32.System.Antimalware.IAntimalwareProvider
    _iid_ = Guid('{7c1e6570-3f73-4e0f-8ad4-98b94cd3290f}')
    @commethod(6)
    def Notify(self, buffer: VoidPtr, length: UInt32, contentName: win32more.Windows.Win32.Foundation.PWSTR, appName: win32more.Windows.Win32.Foundation.PWSTR, pResult: POINTER(win32more.Windows.Win32.System.Antimalware.AMSI_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAntimalwareUacProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b2cabfe4-fe04-42b1-a5df-08d483d4d125}')
    @commethod(3)
    def UacScan(self, context: POINTER(win32more.Windows.Win32.System.Antimalware.AMSI_UAC_REQUEST_CONTEXT), result: POINTER(win32more.Windows.Win32.System.Antimalware.AMSI_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DisplayName(self, displayName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage
import win32more.Windows.Storage.AccessCache
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class AccessCacheOptions(Enum, UInt32):
    None_ = 0
    DisallowUserInput = 1
    FastLocationsOnly = 2
    UseReadOnlyCachedCopy = 4
    SuppressAccessTimeUpdate = 8
class AccessListEntry(Structure):
    Token: WinRT_String
    Metadata: WinRT_String
class AccessListEntryView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.Storage.AccessCache.AccessListEntry]]
    default_interface: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.AccessCache.AccessListEntry]
    _classid_ = 'Windows.Storage.AccessCache.AccessListEntryView'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.AccessCache.AccessListEntry], index: UInt32) -> win32more.Windows.Storage.AccessCache.AccessListEntry: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.AccessCache.AccessListEntry]) -> UInt32: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.AccessCache.AccessListEntry], value: win32more.Windows.Storage.AccessCache.AccessListEntry, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.AccessCache.AccessListEntry], startIndex: UInt32, items: FillArray[win32more.Windows.Storage.AccessCache.AccessListEntry]) -> UInt32: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Storage.AccessCache.AccessListEntry]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Storage.AccessCache.AccessListEntry]: ...
    Size = property(get_Size, None)
class IItemRemovedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.AccessCache.IItemRemovedEventArgs'
    _iid_ = Guid('{59677e5c-55be-4c66-ba66-5eaea79d2631}')
    @winrt_commethod(6)
    def get_RemovedEntry(self) -> win32more.Windows.Storage.AccessCache.AccessListEntry: ...
    RemovedEntry = property(get_RemovedEntry, None)
class IStorageApplicationPermissionsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.AccessCache.IStorageApplicationPermissionsStatics'
    _iid_ = Guid('{4391dfaa-d033-48f9-8060-3ec847d2e3f1}')
    @winrt_commethod(6)
    def get_FutureAccessList(self) -> win32more.Windows.Storage.AccessCache.StorageItemAccessList: ...
    @winrt_commethod(7)
    def get_MostRecentlyUsedList(self) -> win32more.Windows.Storage.AccessCache.StorageItemMostRecentlyUsedList: ...
    FutureAccessList = property(get_FutureAccessList, None)
    MostRecentlyUsedList = property(get_MostRecentlyUsedList, None)
class IStorageApplicationPermissionsStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.AccessCache.IStorageApplicationPermissionsStatics2'
    _iid_ = Guid('{072716ec-aa05-4294-9a11-1a3d04519ad0}')
    @winrt_commethod(6)
    def GetFutureAccessListForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Storage.AccessCache.StorageItemAccessList: ...
    @winrt_commethod(7)
    def GetMostRecentlyUsedListForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Storage.AccessCache.StorageItemMostRecentlyUsedList: ...
class IStorageItemAccessList(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.AccessCache.IStorageItemAccessList'
    _iid_ = Guid('{2caff6ad-de90-47f5-b2c3-dd36c9fdd453}')
    @winrt_commethod(6)
    def AddOverloadDefaultMetadata(self, file: win32more.Windows.Storage.IStorageItem) -> WinRT_String: ...
    @winrt_commethod(7)
    def Add(self, file: win32more.Windows.Storage.IStorageItem, metadata: WinRT_String) -> WinRT_String: ...
    @winrt_commethod(8)
    def AddOrReplaceOverloadDefaultMetadata(self, token: WinRT_String, file: win32more.Windows.Storage.IStorageItem) -> Void: ...
    @winrt_commethod(9)
    def AddOrReplace(self, token: WinRT_String, file: win32more.Windows.Storage.IStorageItem, metadata: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def GetItemAsync(self, token: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.IStorageItem]: ...
    @winrt_commethod(11)
    def GetFileAsync(self, token: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_commethod(12)
    def GetFolderAsync(self, token: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_commethod(13)
    def GetItemWithOptionsAsync(self, token: WinRT_String, options: win32more.Windows.Storage.AccessCache.AccessCacheOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.IStorageItem]: ...
    @winrt_commethod(14)
    def GetFileWithOptionsAsync(self, token: WinRT_String, options: win32more.Windows.Storage.AccessCache.AccessCacheOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_commethod(15)
    def GetFolderWithOptionsAsync(self, token: WinRT_String, options: win32more.Windows.Storage.AccessCache.AccessCacheOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_commethod(16)
    def Remove(self, token: WinRT_String) -> Void: ...
    @winrt_commethod(17)
    def ContainsItem(self, token: WinRT_String) -> Boolean: ...
    @winrt_commethod(18)
    def Clear(self) -> Void: ...
    @winrt_commethod(19)
    def CheckAccess(self, file: win32more.Windows.Storage.IStorageItem) -> Boolean: ...
    @winrt_commethod(20)
    def get_Entries(self) -> win32more.Windows.Storage.AccessCache.AccessListEntryView: ...
    @winrt_commethod(21)
    def get_MaximumItemsAllowed(self) -> UInt32: ...
    Entries = property(get_Entries, None)
    MaximumItemsAllowed = property(get_MaximumItemsAllowed, None)
class IStorageItemMostRecentlyUsedList(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.AccessCache.IStorageItemMostRecentlyUsedList'
    _iid_ = Guid('{016239d5-510d-411e-8cf1-c3d1effa4c33}')
    @winrt_commethod(6)
    def add_ItemRemoved(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.AccessCache.StorageItemMostRecentlyUsedList, win32more.Windows.Storage.AccessCache.ItemRemovedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_ItemRemoved(self, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ItemRemoved = event()
class IStorageItemMostRecentlyUsedList2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.AccessCache.IStorageItemMostRecentlyUsedList2'
    _iid_ = Guid('{da481ea0-ed8d-4731-a1db-e44ee2204093}')
    @winrt_commethod(6)
    def AddWithMetadataAndVisibility(self, file: win32more.Windows.Storage.IStorageItem, metadata: WinRT_String, visibility: win32more.Windows.Storage.AccessCache.RecentStorageItemVisibility) -> WinRT_String: ...
    @winrt_commethod(7)
    def AddOrReplaceWithMetadataAndVisibility(self, token: WinRT_String, file: win32more.Windows.Storage.IStorageItem, metadata: WinRT_String, visibility: win32more.Windows.Storage.AccessCache.RecentStorageItemVisibility) -> Void: ...
class ItemRemovedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.AccessCache.IItemRemovedEventArgs
    _classid_ = 'Windows.Storage.AccessCache.ItemRemovedEventArgs'
    @winrt_mixinmethod
    def get_RemovedEntry(self: win32more.Windows.Storage.AccessCache.IItemRemovedEventArgs) -> win32more.Windows.Storage.AccessCache.AccessListEntry: ...
    RemovedEntry = property(get_RemovedEntry, None)
class RecentStorageItemVisibility(Enum, Int32):
    AppOnly = 0
    AppAndSystem = 1
class _StorageApplicationPermissions_Meta_(ComPtr.__class__):
    pass
class StorageApplicationPermissions(ComPtr, metaclass=_StorageApplicationPermissions_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.AccessCache.StorageApplicationPermissions'
    @winrt_classmethod
    def GetFutureAccessListForUser(cls: win32more.Windows.Storage.AccessCache.IStorageApplicationPermissionsStatics2, user: win32more.Windows.System.User) -> win32more.Windows.Storage.AccessCache.StorageItemAccessList: ...
    @winrt_classmethod
    def GetMostRecentlyUsedListForUser(cls: win32more.Windows.Storage.AccessCache.IStorageApplicationPermissionsStatics2, user: win32more.Windows.System.User) -> win32more.Windows.Storage.AccessCache.StorageItemMostRecentlyUsedList: ...
    @winrt_classmethod
    def get_FutureAccessList(cls: win32more.Windows.Storage.AccessCache.IStorageApplicationPermissionsStatics) -> win32more.Windows.Storage.AccessCache.StorageItemAccessList: ...
    @winrt_classmethod
    def get_MostRecentlyUsedList(cls: win32more.Windows.Storage.AccessCache.IStorageApplicationPermissionsStatics) -> win32more.Windows.Storage.AccessCache.StorageItemMostRecentlyUsedList: ...
    _StorageApplicationPermissions_Meta_.FutureAccessList = property(get_FutureAccessList, None)
    _StorageApplicationPermissions_Meta_.MostRecentlyUsedList = property(get_MostRecentlyUsedList, None)
class StorageItemAccessList(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.AccessCache.IStorageItemAccessList
    _classid_ = 'Windows.Storage.AccessCache.StorageItemAccessList'
    @winrt_mixinmethod
    def AddOverloadDefaultMetadata(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, file: win32more.Windows.Storage.IStorageItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def Add(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, file: win32more.Windows.Storage.IStorageItem, metadata: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def AddOrReplaceOverloadDefaultMetadata(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String, file: win32more.Windows.Storage.IStorageItem) -> Void: ...
    @winrt_mixinmethod
    def AddOrReplace(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String, file: win32more.Windows.Storage.IStorageItem, metadata: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetItemAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.IStorageItem]: ...
    @winrt_mixinmethod
    def GetFileAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def GetFolderAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_mixinmethod
    def GetItemWithOptionsAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String, options: win32more.Windows.Storage.AccessCache.AccessCacheOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.IStorageItem]: ...
    @winrt_mixinmethod
    def GetFileWithOptionsAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String, options: win32more.Windows.Storage.AccessCache.AccessCacheOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def GetFolderWithOptionsAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String, options: win32more.Windows.Storage.AccessCache.AccessCacheOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def ContainsItem(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList) -> Void: ...
    @winrt_mixinmethod
    def CheckAccess(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, file: win32more.Windows.Storage.IStorageItem) -> Boolean: ...
    @winrt_mixinmethod
    def get_Entries(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList) -> win32more.Windows.Storage.AccessCache.AccessListEntryView: ...
    @winrt_mixinmethod
    def get_MaximumItemsAllowed(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList) -> UInt32: ...
    Entries = property(get_Entries, None)
    MaximumItemsAllowed = property(get_MaximumItemsAllowed, None)
class StorageItemMostRecentlyUsedList(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.AccessCache.IStorageItemMostRecentlyUsedList
    _classid_ = 'Windows.Storage.AccessCache.StorageItemMostRecentlyUsedList'
    @winrt_mixinmethod
    def add_ItemRemoved(self: win32more.Windows.Storage.AccessCache.IStorageItemMostRecentlyUsedList, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.AccessCache.StorageItemMostRecentlyUsedList, win32more.Windows.Storage.AccessCache.ItemRemovedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemRemoved(self: win32more.Windows.Storage.AccessCache.IStorageItemMostRecentlyUsedList, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def AddOverloadDefaultMetadata(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, file: win32more.Windows.Storage.IStorageItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def Add(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, file: win32more.Windows.Storage.IStorageItem, metadata: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def AddOrReplaceOverloadDefaultMetadata(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String, file: win32more.Windows.Storage.IStorageItem) -> Void: ...
    @winrt_mixinmethod
    def AddOrReplace(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String, file: win32more.Windows.Storage.IStorageItem, metadata: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetItemAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.IStorageItem]: ...
    @winrt_mixinmethod
    def GetFileAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def GetFolderAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_mixinmethod
    def GetItemWithOptionsAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String, options: win32more.Windows.Storage.AccessCache.AccessCacheOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.IStorageItem]: ...
    @winrt_mixinmethod
    def GetFileWithOptionsAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String, options: win32more.Windows.Storage.AccessCache.AccessCacheOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def GetFolderWithOptionsAsync(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String, options: win32more.Windows.Storage.AccessCache.AccessCacheOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def ContainsItem(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, token: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList) -> Void: ...
    @winrt_mixinmethod
    def CheckAccess(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList, file: win32more.Windows.Storage.IStorageItem) -> Boolean: ...
    @winrt_mixinmethod
    def get_Entries(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList) -> win32more.Windows.Storage.AccessCache.AccessListEntryView: ...
    @winrt_mixinmethod
    def get_MaximumItemsAllowed(self: win32more.Windows.Storage.AccessCache.IStorageItemAccessList) -> UInt32: ...
    @winrt_mixinmethod
    def AddWithMetadataAndVisibility(self: win32more.Windows.Storage.AccessCache.IStorageItemMostRecentlyUsedList2, file: win32more.Windows.Storage.IStorageItem, metadata: WinRT_String, visibility: win32more.Windows.Storage.AccessCache.RecentStorageItemVisibility) -> WinRT_String: ...
    @winrt_mixinmethod
    def AddOrReplaceWithMetadataAndVisibility(self: win32more.Windows.Storage.AccessCache.IStorageItemMostRecentlyUsedList2, token: WinRT_String, file: win32more.Windows.Storage.IStorageItem, metadata: WinRT_String, visibility: win32more.Windows.Storage.AccessCache.RecentStorageItemVisibility) -> Void: ...
    Entries = property(get_Entries, None)
    MaximumItemsAllowed = property(get_MaximumItemsAllowed, None)
    ItemRemoved = event()


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Data.Xml.MsXml
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Media.DirectShow
import win32more.Windows.Win32.Media.DirectShow.Xml
import win32more.Windows.Win32.System.Com
CLSID_XMLGraphBuilder: Guid = Guid('{1bb05961-5fbf-11d2-a521-44df07c10000}')
class IXMLGraphBuilder(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1bb05960-5fbf-11d2-a521-44df07c10000}')
    @commethod(3)
    def BuildFromXML(self, pGraph: win32more.Windows.Win32.Media.DirectShow.IGraphBuilder, pxml: win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SaveToXML(self, pGraph: win32more.Windows.Win32.Media.DirectShow.IGraphBuilder, pbstrxml: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def BuildFromXMLFile(self, pGraph: win32more.Windows.Win32.Media.DirectShow.IGraphBuilder, wszFileName: win32more.Windows.Win32.Foundation.PWSTR, wszBaseURL: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Management.Workplace
import win32more.Windows.Win32.System.WinRT
class IMdmAllowPolicyStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Workplace.IMdmAllowPolicyStatics'
    _iid_ = Guid('{c39709e7-741c-41f2-a4b6-314c31502586}')
    @winrt_commethod(6)
    def IsBrowserAllowed(self) -> Boolean: ...
    @winrt_commethod(7)
    def IsCameraAllowed(self) -> Boolean: ...
    @winrt_commethod(8)
    def IsMicrosoftAccountAllowed(self) -> Boolean: ...
    @winrt_commethod(9)
    def IsStoreAllowed(self) -> Boolean: ...
class IMdmPolicyStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Workplace.IMdmPolicyStatics2'
    _iid_ = Guid('{c99c7526-03d4-49f9-a993-43efccd265c4}')
    @winrt_commethod(6)
    def GetMessagingSyncPolicy(self) -> win32more.Windows.Management.Workplace.MessagingSyncPolicy: ...
class IWorkplaceSettingsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Workplace.IWorkplaceSettingsStatics'
    _iid_ = Guid('{e4676ffd-2d92-4c08-bad4-f6590b54a6d3}')
    @winrt_commethod(6)
    def get_IsMicrosoftAccountOptional(self) -> Boolean: ...
    IsMicrosoftAccountOptional = property(get_IsMicrosoftAccountOptional, None)
class MdmPolicy(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Workplace.MdmPolicy'
    @winrt_classmethod
    def GetMessagingSyncPolicy(cls: win32more.Windows.Management.Workplace.IMdmPolicyStatics2) -> win32more.Windows.Management.Workplace.MessagingSyncPolicy: ...
    @winrt_classmethod
    def IsBrowserAllowed(cls: win32more.Windows.Management.Workplace.IMdmAllowPolicyStatics) -> Boolean: ...
    @winrt_classmethod
    def IsCameraAllowed(cls: win32more.Windows.Management.Workplace.IMdmAllowPolicyStatics) -> Boolean: ...
    @winrt_classmethod
    def IsMicrosoftAccountAllowed(cls: win32more.Windows.Management.Workplace.IMdmAllowPolicyStatics) -> Boolean: ...
    @winrt_classmethod
    def IsStoreAllowed(cls: win32more.Windows.Management.Workplace.IMdmAllowPolicyStatics) -> Boolean: ...
class MessagingSyncPolicy(Enum, Int32):
    Disallowed = 0
    Allowed = 1
    Required = 2
class _WorkplaceSettings_Meta_(ComPtr.__class__):
    pass
class WorkplaceSettings(ComPtr, metaclass=_WorkplaceSettings_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Workplace.WorkplaceSettings'
    @winrt_classmethod
    def get_IsMicrosoftAccountOptional(cls: win32more.Windows.Management.Workplace.IWorkplaceSettingsStatics) -> Boolean: ...
    _WorkplaceSettings_Meta_.IsMicrosoftAccountOptional = property(get_IsMicrosoftAccountOptional, None)
WorkplaceSettingsContract: UInt32 = 65536


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.DataTransfer
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Services.Cortana
import win32more.Windows.Storage.Streams
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class CortanaActionableInsights(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Cortana.ICortanaActionableInsights
    _classid_ = 'Windows.Services.Cortana.CortanaActionableInsights'
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Services.Cortana.ICortanaActionableInsights) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def IsAvailableAsync(self: win32more.Windows.Services.Cortana.ICortanaActionableInsights) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def ShowInsightsForImageAsync(self: win32more.Windows.Services.Cortana.ICortanaActionableInsights, imageStream: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ShowInsightsForImageWithOptionsAsync(self: win32more.Windows.Services.Cortana.ICortanaActionableInsights, imageStream: win32more.Windows.Storage.Streams.IRandomAccessStreamReference, options: win32more.Windows.Services.Cortana.CortanaActionableInsightsOptions) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ShowInsightsForTextAsync(self: win32more.Windows.Services.Cortana.ICortanaActionableInsights, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ShowInsightsForTextWithOptionsAsync(self: win32more.Windows.Services.Cortana.ICortanaActionableInsights, text: WinRT_String, options: win32more.Windows.Services.Cortana.CortanaActionableInsightsOptions) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ShowInsightsAsync(self: win32more.Windows.Services.Cortana.ICortanaActionableInsights, datapackage: win32more.Windows.ApplicationModel.DataTransfer.DataPackage) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ShowInsightsWithOptionsAsync(self: win32more.Windows.Services.Cortana.ICortanaActionableInsights, datapackage: win32more.Windows.ApplicationModel.DataTransfer.DataPackage, options: win32more.Windows.Services.Cortana.CortanaActionableInsightsOptions) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Windows.Services.Cortana.ICortanaActionableInsightsStatics) -> win32more.Windows.Services.Cortana.CortanaActionableInsights: ...
    @winrt_classmethod
    def GetForUser(cls: win32more.Windows.Services.Cortana.ICortanaActionableInsightsStatics, user: win32more.Windows.System.User) -> win32more.Windows.Services.Cortana.CortanaActionableInsights: ...
    User = property(get_User, None)
class CortanaActionableInsightsOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Cortana.ICortanaActionableInsightsOptions
    _classid_ = 'Windows.Services.Cortana.CortanaActionableInsightsOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Services.Cortana.CortanaActionableInsightsOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Services.Cortana.CortanaActionableInsightsOptions: ...
    @winrt_mixinmethod
    def get_ContentSourceWebLink(self: win32more.Windows.Services.Cortana.ICortanaActionableInsightsOptions) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_ContentSourceWebLink(self: win32more.Windows.Services.Cortana.ICortanaActionableInsightsOptions, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_SurroundingText(self: win32more.Windows.Services.Cortana.ICortanaActionableInsightsOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SurroundingText(self: win32more.Windows.Services.Cortana.ICortanaActionableInsightsOptions, value: WinRT_String) -> Void: ...
    ContentSourceWebLink = property(get_ContentSourceWebLink, put_ContentSourceWebLink)
    SurroundingText = property(get_SurroundingText, put_SurroundingText)
class CortanaPermission(Enum, Int32):
    BrowsingHistory = 0
    Calendar = 1
    CallHistory = 2
    Contacts = 3
    Email = 4
    InputPersonalization = 5
    Location = 6
    Messaging = 7
    Microphone = 8
    Personalization = 9
    PhoneCall = 10
class CortanaPermissionsChangeResult(Enum, Int32):
    Success = 0
    Unavailable = 1
    DisabledByPolicy = 2
class CortanaPermissionsManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Cortana.ICortanaPermissionsManager
    _classid_ = 'Windows.Services.Cortana.CortanaPermissionsManager'
    @winrt_mixinmethod
    def IsSupported(self: win32more.Windows.Services.Cortana.ICortanaPermissionsManager) -> Boolean: ...
    @winrt_mixinmethod
    def ArePermissionsGrantedAsync(self: win32more.Windows.Services.Cortana.ICortanaPermissionsManager, permissions: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Services.Cortana.CortanaPermission]) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def GrantPermissionsAsync(self: win32more.Windows.Services.Cortana.ICortanaPermissionsManager, permissions: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Services.Cortana.CortanaPermission]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Services.Cortana.CortanaPermissionsChangeResult]: ...
    @winrt_mixinmethod
    def RevokePermissionsAsync(self: win32more.Windows.Services.Cortana.ICortanaPermissionsManager, permissions: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Services.Cortana.CortanaPermission]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Services.Cortana.CortanaPermissionsChangeResult]: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Windows.Services.Cortana.ICortanaPermissionsManagerStatics) -> win32more.Windows.Services.Cortana.CortanaPermissionsManager: ...
class CortanaSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Services.Cortana.ICortanaSettings
    _classid_ = 'Windows.Services.Cortana.CortanaSettings'
    @winrt_mixinmethod
    def get_HasUserConsentToVoiceActivation(self: win32more.Windows.Services.Cortana.ICortanaSettings) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsVoiceActivationEnabled(self: win32more.Windows.Services.Cortana.ICortanaSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVoiceActivationEnabled(self: win32more.Windows.Services.Cortana.ICortanaSettings, value: Boolean) -> Void: ...
    @winrt_classmethod
    def IsSupported(cls: win32more.Windows.Services.Cortana.ICortanaSettingsStatics) -> Boolean: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Windows.Services.Cortana.ICortanaSettingsStatics) -> win32more.Windows.Services.Cortana.CortanaSettings: ...
    HasUserConsentToVoiceActivation = property(get_HasUserConsentToVoiceActivation, None)
    IsVoiceActivationEnabled = property(get_IsVoiceActivationEnabled, put_IsVoiceActivationEnabled)
class ICortanaActionableInsights(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Cortana.ICortanaActionableInsights'
    _iid_ = Guid('{951ec6b1-fc83-586d-8b84-2452c8981625}')
    @winrt_commethod(6)
    def get_User(self) -> win32more.Windows.System.User: ...
    @winrt_commethod(7)
    def IsAvailableAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(8)
    def ShowInsightsForImageAsync(self, imageStream: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def ShowInsightsForImageWithOptionsAsync(self, imageStream: win32more.Windows.Storage.Streams.IRandomAccessStreamReference, options: win32more.Windows.Services.Cortana.CortanaActionableInsightsOptions) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(10)
    def ShowInsightsForTextAsync(self, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(11)
    def ShowInsightsForTextWithOptionsAsync(self, text: WinRT_String, options: win32more.Windows.Services.Cortana.CortanaActionableInsightsOptions) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(12)
    def ShowInsightsAsync(self, datapackage: win32more.Windows.ApplicationModel.DataTransfer.DataPackage) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(13)
    def ShowInsightsWithOptionsAsync(self, datapackage: win32more.Windows.ApplicationModel.DataTransfer.DataPackage, options: win32more.Windows.Services.Cortana.CortanaActionableInsightsOptions) -> win32more.Windows.Foundation.IAsyncAction: ...
    User = property(get_User, None)
class ICortanaActionableInsightsOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Cortana.ICortanaActionableInsightsOptions'
    _iid_ = Guid('{aac2bbcf-9782-5420-b81e-7ae56af31815}')
    @winrt_commethod(6)
    def get_ContentSourceWebLink(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_ContentSourceWebLink(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def get_SurroundingText(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_SurroundingText(self, value: WinRT_String) -> Void: ...
    ContentSourceWebLink = property(get_ContentSourceWebLink, put_ContentSourceWebLink)
    SurroundingText = property(get_SurroundingText, put_SurroundingText)
class ICortanaActionableInsightsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Cortana.ICortanaActionableInsightsStatics'
    _iid_ = Guid('{b5ded412-9d2f-5cb5-9b05-356a0b836c10}')
    @winrt_commethod(6)
    def GetDefault(self) -> win32more.Windows.Services.Cortana.CortanaActionableInsights: ...
    @winrt_commethod(7)
    def GetForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Services.Cortana.CortanaActionableInsights: ...
class ICortanaPermissionsManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Cortana.ICortanaPermissionsManager'
    _iid_ = Guid('{191330e0-8695-438a-9545-3da4e822ddb4}')
    @winrt_commethod(6)
    def IsSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def ArePermissionsGrantedAsync(self, permissions: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Services.Cortana.CortanaPermission]) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(8)
    def GrantPermissionsAsync(self, permissions: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Services.Cortana.CortanaPermission]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Services.Cortana.CortanaPermissionsChangeResult]: ...
    @winrt_commethod(9)
    def RevokePermissionsAsync(self, permissions: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Services.Cortana.CortanaPermission]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Services.Cortana.CortanaPermissionsChangeResult]: ...
class ICortanaPermissionsManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Cortana.ICortanaPermissionsManagerStatics'
    _iid_ = Guid('{76b1e67a-b045-4414-9d6d-2ad3a5fe3a7e}')
    @winrt_commethod(6)
    def GetDefault(self) -> win32more.Windows.Services.Cortana.CortanaPermissionsManager: ...
class ICortanaSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Cortana.ICortanaSettings'
    _iid_ = Guid('{54d571a7-8062-40f4-abe7-dedfd697b019}')
    @winrt_commethod(6)
    def get_HasUserConsentToVoiceActivation(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsVoiceActivationEnabled(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_IsVoiceActivationEnabled(self, value: Boolean) -> Void: ...
    HasUserConsentToVoiceActivation = property(get_HasUserConsentToVoiceActivation, None)
    IsVoiceActivationEnabled = property(get_IsVoiceActivationEnabled, put_IsVoiceActivationEnabled)
class ICortanaSettingsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Services.Cortana.ICortanaSettingsStatics'
    _iid_ = Guid('{8b2ccd7e-2ec0-446d-9285-33f07ce8ac04}')
    @winrt_commethod(6)
    def IsSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def GetDefault(self) -> win32more.Windows.Services.Cortana.CortanaSettings: ...


make_ready(__name__)
